from . import book_id, combine_pages, download_pages
import argparse


def main():
    parser = argparse.ArgumentParser(
        prog="pearson_pdf", description="Download Pearson books as PDFs."
    )
    parser.add_argument(
        "-u", "--url", action="store_true", help="Parse Book ID from URL"
    )
    parser.add_argument("book_id", type=str, help="Book ID used to fetch pages")
    parser.add_argument("save_path", type=str, help="Path to save PDF")
    args = parser.parse_args()

    if args.url:
        args.book_id = book_id(args.book_id)
    combine_pages(download_pages(args.book_id), args.save_path)


if __name__ == "__main__":
    main()



import setuptools


with open("README.md", "r", encoding="utf-8") as readme:
    long_description = readme.read()


setuptools.setup(
    name="pearson-pdf",
    version="1.0.4",
    author="jyooru",
    license="MIT",
    description="Tool to download Pearson books as PDFs.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/jyooru/pearson-pdf",
    project_urls={
        "Source": "https://github.com/jyooru/pearson-pdf",
        "Issues": "https://github.com/jyooru/pearson-pdf/issues",
    },
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Intended Audience :: End Users/Desktop",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    keywords="pearson, ebook, pearson-ebook, pdf, pearson-pdf",
    packages=setuptools.find_packages(exclude=["tests"]),
    install_requires=["requests", "pillow"],
    python_requires=">=3.9",  # TODO: support more versions
    entry_points={"console_scripts": ["pearson_pdf=pearson_pdf.__main__:main"]},
)



import requests
from io import BytesIO
from PIL import Image
import string


def book_id(book_url: str):
    book_id = book_url
    if "generated" in book_url:
        book_id = book_id.split("generated")[1]
    if "foxit-assets" in book_url:
        book_id = book_id.split("foxit-assets")[0]
    allowed_characters = string.ascii_letters + string.digits + "-"
    return "".join(
        [character for character in book_id if character in allowed_characters]
    )


def book_url(book_id: str):
    return (
        "https://d2f01w1orx96i0.cloudfront.net/resources/products/epubs/generated/"
        + book_id
        + "/foxit-assets/pages/page"
    )


def download_pages(book_id: str):
    pages = []
    pages_url = book_url(book_id)
    while True:
        response = requests.get(pages_url + str(len(pages)))
        if response.status_code == 200:
            pages.append(Image.open(BytesIO(response.content)))
        elif response.status_code == 403:
            break
        else:
            raise Exception('unexpected status code "' + response.status_code + '"')
    return pages


def combine_pages(pages: list, path: str, format: str = "PDF", resolution: int = 100):
    page_0 = pages[0]
    pages.pop(0)
    page_0.save(path, format, resolution=resolution, save_all=True, append_images=pages)
